#!/usr/bin/env python
import os
import sys
import re
import argparse
from p2.store.client import Client

"""
* workflow
    * input params:
        * report component name (ex:“p2.reporter.access”)
        * report tag
        * output directory
    * open <title>.csv
    * get p2.store.client
    * get report config params
    * select report record id by title, tag
    * select all report entries with that id as parent id
    * print ucfirst report.config.report.cols
    * for each entry:
        * applies lut and regexes
        * print entry
    * close report csv file
"""

parser = argparse.ArgumentParser(
    description='A script to fetch a report on p2.store')
parser.add_argument( '--output',
                    default=sys.stdout,
                    type=argparse.FileType('w'),
            help='the report CSV file')
parser.add_argument( '--component',
                    required=True,
                    help='The report component label')
parser.add_argument( '--tag',
                    required=True,
                    help='The report tag label')

args = parser.parse_args()

client = Client(os.getenv('P2_STORE_URL')) or exit("No p2.store.client")

report_config = client.get_config(
    component=args.component,
    tag=args.tag) or exit("No config found")

recs = client.select(
    table="reports",
    fetch=['id'],
    sort='id desc',
    limit=1,
    filter={
        'title': report_config[args.tag]['report']['title'],
        'tag': args.tag
    })

filter = dict()
if len(recs):
    report_id = recs[0]['id'] or exit("No report id found")
    filter = {'report_id':report_id}
else:
    filter = report_config[args.tag]['report'].get('query', {}).get('filter', {})

sort = report_config[args.tag]['report'].get('query', {}).get('sort')
fetch = report_config[args.tag]['report'].get('query', {}).get('fetch', ['body'])
table = report_config[args.tag]['report'].get('query', {}).get('table', 'report_entries')
entries = client.select(
    table=table,
    fetch=fetch,
    sort=sort,
    filter=filter
)

if 'cols' not in report_config[args.tag]['report']:
    print("cols not defined, exiting...")
    exit()

first_row = list(report_config[args.tag]['report']['cols'])
args.output.write("{}".format(', '.join(l.capitalize() for l in first_row)))
args.output.write("\n")

# for entry in entries_sorted:
for entry in entries:
    line=""
    for col in report_config[args.tag]['report']['cols'][:-1]:
        if 'regexes' in report_config[args.tag]['report']:
            for key in report_config[args.tag]['report']['regexes']:
                r = re.compile(report_config[args.tag]['report']['regexes'][key])
                match = r.match(entry[key])
                entry[key] = match.group()
        line += f"{entry[col]}, "
    line += f"{entry[report_config[args.tag]['report']['cols'][-1]]}"
    args.output.write(f"{line}\n")
args.output.close()
