#!/usr/bin/env python
import logging
import argparse
import json

# from p2.Reporter import get_driver
from p2.tools.driver import get_driver
from p2.logging import HttpLogger


"""
Workflow:
- get driver from input params
- get driver object
- driver.get_config
- driver.create_report_profile
- driver.prepare_report_rows
- driver.store_report_rows
"""


parser = argparse.ArgumentParser()
parser.add_argument('--driver', help='p2.reporter driver module', required=True)
parser.add_argument('--tag', help='component configuration tag', required=True)
args = parser.parse_args()
driver = args.driver
tag = args.tag
package = 'p2.reporter.'+driver

# this expects the P2_STORE_URL envar...
log_obj = HttpLogger(
    level = logging.DEBUG,
    silent = False,
    name = package
)
log = log_obj.getLogger()

log.info(f"Reporter: {package}")

driver_obj = get_driver(
    module='p2.reporter',
    driver=driver,
    class_name='Reporter',
    **{'tag':tag}
    )
if driver_obj is None:
    log.error(f"Error: object for {package} is None, exiting..." )
    exit(-1)

for tag in driver_obj.config.keys():
    log.info(f"Going to create report for tag {tag}")
    log.debug("Config for tag {}: {}".format(
        tag, json.dumps(driver_obj.config[tag], indent=2)))

    driver_obj.create_report_profile(
        title=driver_obj.config[tag].get('report', {}).get('title', 'No title'),
        tag=tag,
        report_type=driver_obj.config[tag].get('report', {}).get('report_type', 'no_report_type'),
        description=driver_obj.config[tag].get('report', {}).get('description','No description'),
        params=json.dumps(driver_obj.config, indent=2)
    )
    if driver_obj.report_id is None:
        log.error("Error storing a report profile, exiting...")
        exit(-3)
    log.info(f"Report id: {driver_obj.report_id}")
    rows = driver_obj.prepare_report_rows(tag)
    driver_obj.store_report_rows(rows)
