#!/usr/bin/env python
import unittest
import os
from p2.tools.prepare_db import setUpDB, tearDownDB
from p2.tools.driver import get_driver
from p2.store.client import Client


class TestP2Reporter(unittest.TestCase):

    def setUp(self):
        # setUpDB()
        self.client = Client(os.getenv('P2_STORE_URL'))
        self.assertIsNotNone(self.client)
        self.driver = get_driver(
            module='p2.reporter',
            driver='fake',
            class_name='Reporter',
            **{'tag':'minikube'}
        )
        self.assertIsNotNone(self.driver)

    def tearDown(self):
        # tearDownDB()
        pass

    def test_get_config(self):
        self.assertEqual(self.driver.config['minikube']['report']['report_type'], 'fake_report')

    def test_create_report_profile(self):
        self.driver.create_report_profile(
            tag='fake_report',
            title='Fake report',
            report_type='fake'
        )
        self.assertGreater(self.driver.report_id, 1)
        rows = self.driver.prepare_report_rows(self.driver.config['minikube']['report']['tag'])
        ret = self.driver.store_report_rows(rows=rows)
        self.assertEqual(ret, len(rows))

        #get the same report and check...
        report = self.client.select(
            table='reports',
            fetch=['id', 'title'],
            filter={'tag':'fake_report'}
        )
        self.assertIsNotNone(report)
        self.assertEqual(report[0]['title'], 'Fake report')
        self.assertEqual(report[0]['id'], self.driver.report_id)
